"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = require("react");

var _core = require("@emotion/core");

var _constants = require("@atlaskit/theme/constants");

var _theme = require("../theme");

/** @jsx jsx */
var containerStyles = (0, _core.css)({
  display: 'inline-block',
  boxSizing: 'border-box',
  maxWidth: '100%',
  padding: '2px 0 3px 0',
  borderRadius: (0, _constants.borderRadius)(),
  fontSize: '11px',
  fontWeight: 700,
  lineHeight: 1,
  textTransform: 'uppercase',
  verticalAlign: 'baseline'
});
var contentStyles = (0, _core.css)({
  display: 'inline-block',
  boxSizing: 'border-box',
  width: '100%',
  padding: "0 ".concat((0, _constants.gridSize)() / 2, "px"),
  overflow: 'hidden',
  textOverflow: 'ellipsis',
  verticalAlign: 'top',
  whiteSpace: 'nowrap'
});
/**
 * __Lozenge__
 *
 * A lozenge is a visual indicator used to highlight an item's status for quick recognition.
 *
 * - [Examples](https://atlassian.design/components/lozenge/examples)
 * - [Code](https://atlassian.design/components/lozenge/code)
 * - [Usage](https://atlassian.design/components/lozenge/usage)
 */

var Lozenge = /*#__PURE__*/(0, _react.memo)(function (_ref) {
  var children = _ref.children,
      testId = _ref.testId,
      _ref$isBold = _ref.isBold,
      isBold = _ref$isBold === void 0 ? false : _ref$isBold,
      _ref$appearance = _ref.appearance,
      appearance = _ref$appearance === void 0 ? 'default' : _ref$appearance,
      _ref$maxWidth = _ref.maxWidth,
      maxWidth = _ref$maxWidth === void 0 ? 200 : _ref$maxWidth,
      _ref$style = _ref.style,
      style = _ref$style === void 0 ? {} : _ref$style;
  var backgroundColor = style.backgroundColor || (isBold ? _theme.boldBackgroundColor[appearance] : _theme.defaultBackgroundColor[appearance]).light;
  var color = style.color || (isBold ? _theme.boldTextColor[appearance] : _theme.defaultTextColor[appearance]).light;
  return (0, _core.jsx)("span", {
    style: {
      backgroundColor: backgroundColor,
      color: color
    },
    css: containerStyles,
    "data-testid": testId
  }, (0, _core.jsx)("span", {
    style: {
      maxWidth: maxWidth
    },
    css: contentStyles
  }, children));
});
Lozenge.displayName = 'Lozenge';
var _default = Lozenge;
exports.default = _default;