/** @jsx jsx */
import { memo } from 'react';
import { css, jsx } from '@emotion/core';
import { borderRadius, gridSize } from '@atlaskit/theme/constants';
import { boldBackgroundColor, boldTextColor, defaultBackgroundColor, defaultTextColor } from '../theme';
const containerStyles = css({
  display: 'inline-block',
  boxSizing: 'border-box',
  maxWidth: '100%',
  padding: '2px 0 3px 0',
  borderRadius: borderRadius(),
  fontSize: '11px',
  fontWeight: 700,
  lineHeight: 1,
  textTransform: 'uppercase',
  verticalAlign: 'baseline'
});
const contentStyles = css({
  display: 'inline-block',
  boxSizing: 'border-box',
  width: '100%',
  padding: `0 ${gridSize() / 2}px`,
  overflow: 'hidden',
  textOverflow: 'ellipsis',
  verticalAlign: 'top',
  whiteSpace: 'nowrap'
});
/**
 * __Lozenge__
 *
 * A lozenge is a visual indicator used to highlight an item's status for quick recognition.
 *
 * - [Examples](https://atlassian.design/components/lozenge/examples)
 * - [Code](https://atlassian.design/components/lozenge/code)
 * - [Usage](https://atlassian.design/components/lozenge/usage)
 */

const Lozenge = /*#__PURE__*/memo(({
  children,
  testId,
  isBold = false,
  appearance = 'default',
  maxWidth = 200,
  style = {}
}) => {
  const backgroundColor = style.backgroundColor || (isBold ? boldBackgroundColor[appearance] : defaultBackgroundColor[appearance]).light;
  const color = style.color || (isBold ? boldTextColor[appearance] : defaultTextColor[appearance]).light;
  return jsx("span", {
    style: {
      backgroundColor,
      color
    },
    css: containerStyles,
    "data-testid": testId
  }, jsx("span", {
    style: {
      maxWidth
    },
    css: contentStyles
  }, children));
});
Lozenge.displayName = 'Lozenge';
export default Lozenge;