/** @jsx jsx */
import { memo } from 'react';
import { css, jsx } from '@emotion/core';
import { borderRadius, gridSize } from '@atlaskit/theme/constants';
import { boldBackgroundColor, boldTextColor, defaultBackgroundColor, defaultTextColor } from '../theme';
var containerStyles = css({
  display: 'inline-block',
  boxSizing: 'border-box',
  maxWidth: '100%',
  padding: '2px 0 3px 0',
  borderRadius: borderRadius(),
  fontSize: '11px',
  fontWeight: 700,
  lineHeight: 1,
  textTransform: 'uppercase',
  verticalAlign: 'baseline'
});
var contentStyles = css({
  display: 'inline-block',
  boxSizing: 'border-box',
  width: '100%',
  padding: "0 ".concat(gridSize() / 2, "px"),
  overflow: 'hidden',
  textOverflow: 'ellipsis',
  verticalAlign: 'top',
  whiteSpace: 'nowrap'
});
/**
 * __Lozenge__
 *
 * A lozenge is a visual indicator used to highlight an item's status for quick recognition.
 *
 * - [Examples](https://atlassian.design/components/lozenge/examples)
 * - [Code](https://atlassian.design/components/lozenge/code)
 * - [Usage](https://atlassian.design/components/lozenge/usage)
 */

var Lozenge = /*#__PURE__*/memo(function (_ref) {
  var children = _ref.children,
      testId = _ref.testId,
      _ref$isBold = _ref.isBold,
      isBold = _ref$isBold === void 0 ? false : _ref$isBold,
      _ref$appearance = _ref.appearance,
      appearance = _ref$appearance === void 0 ? 'default' : _ref$appearance,
      _ref$maxWidth = _ref.maxWidth,
      maxWidth = _ref$maxWidth === void 0 ? 200 : _ref$maxWidth,
      _ref$style = _ref.style,
      style = _ref$style === void 0 ? {} : _ref$style;
  var backgroundColor = style.backgroundColor || (isBold ? boldBackgroundColor[appearance] : defaultBackgroundColor[appearance]).light;
  var color = style.color || (isBold ? boldTextColor[appearance] : defaultTextColor[appearance]).light;
  return jsx("span", {
    style: {
      backgroundColor: backgroundColor,
      color: color
    },
    css: containerStyles,
    "data-testid": testId
  }, jsx("span", {
    style: {
      maxWidth: maxWidth
    },
    css: contentStyles
  }, children));
});
Lozenge.displayName = 'Lozenge';
export default Lozenge;